=================
Welcome to SigMF!
=================

**SigMF** is a Python library for working with radio recordings in
``.sigmf`` format according to the `SigMF standard <https://sigmf.org/>`_.
It offers a *simple* and *intuitive* API for Python developers.

..
   Note: The toolversion & specversion below are replaced dynamically during build.

This documentation is for version |toolversion| of the library, which is
compatible with version |specversion| of the SigMF specification.

To get started, see the :doc:`quickstart` section or learn how to :ref:`install` the library.

-----

.. toctree::
   :maxdepth: 1
   :caption: Getting Started
   :hidden:

   quickstart
   advanced
   developers

.. toctree::
   :maxdepth: 1
   :caption: Community
   :hidden:

   faq

.. toctree::
   :maxdepth: 1
   :caption: API Reference
   :hidden:

   api
